@@ -5,7 +5,7 @@
 
 //
 //    BEDOPS
-//    Copyright (C) 2011-2017 Shane Neph, Scott Kuehn and Alex Reynolds
+//    Copyright (C) 2011-2018 Shane Neph, Scott Kuehn and Alex Reynolds
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -26,45 +26,59 @@
 #define BEDTYPES_HPP
 
 #include "data/bed/Bed.hpp"
+#include "data/bed/Bed_minmem.hpp"
+#include "suite/BEDOPS.Constants.hpp"
 
 namespace Bed {
 
   /***********************************************/
   /* Typedef helper for user applications        */
   /***********************************************/
-  template <bool UseNonStaticChrom, bool UseRest, typename MType = double>
+  template <bool UseNonStaticChrom, bool UseRest, typename MType = Bed::MeasurementType, bool MemPool = true>
   struct BedTypes {
     typedef MType                                   MeasureType;
     typedef BasicCoords<UseNonStaticChrom, UseRest> Bed3Type;
-    typedef Bed4< Bed3Type, UseRest >               Bed4Type;
-    typedef Bed5< Bed4Type, MeasureType, UseRest >  Bed5Type;
+    typedef Bed4<Bed3Type, UseRest>                 Bed4Type;
+    typedef Bed5<Bed4Type, MeasureType, UseRest>    Bed5Type;
   };
 
-  enum { Rest = true, NoRest = false, OneChrom = false, AllChrom = true };
+  template <bool UseNonStaticChrom, bool UseRest, typename MType>
+  struct BedTypes<UseNonStaticChrom, UseRest, MType, false> {
+    typedef MType                                           MeasureType;
+    typedef NoPool::BasicCoords<UseNonStaticChrom, UseRest> Bed3Type;
+    typedef NoPool::Bed4<Bed3Type, UseRest>                 Bed4Type;
+    typedef NoPool::Bed5<Bed4Type, MeasureType, UseRest>    Bed5Type;
+  };
+
+  enum { Rest = true, NoRest = false, OneChrom = false, AllChrom = true, NoPooling = false };
 
 
   /***********************************************/
   /* Common typedefs                             */
   /***********************************************/
-  typedef BedTypes<AllChrom, Rest, double>    BTAllRest;
-  typedef BedTypes<AllChrom, NoRest, double>  BTAllNoRest;
-  typedef BedTypes<OneChrom, Rest, double>    BTOneRest;
-  typedef BedTypes<OneChrom, NoRest, double>  BTOneNoRest;
-
+  typedef BedTypes<AllChrom, Rest, Bed::MeasurementType>    BTAllRest;
+  typedef BedTypes<AllChrom, NoRest, Bed::MeasurementType>  BTAllNoRest;
   typedef BTAllRest::Bed3Type   B3Rest;
   typedef BTAllNoRest::Bed3Type B3NoRest;
-  typedef BTOneRest::Bed3Type   B3OneChromRest;
-  typedef BTOneNoRest::Bed3Type B3OneChromNoRest;
 
   typedef BTAllRest::Bed4Type   B4Rest;
   typedef BTAllNoRest::Bed4Type B4NoRest;
-  typedef BTOneRest::Bed4Type   B4OneChromRest;
-  typedef BTOneNoRest::Bed4Type B4OneChromNoRest;
 
   typedef BTAllRest::Bed5Type   B5Rest;
   typedef BTAllNoRest::Bed5Type B5NoRest;
-  typedef BTOneRest::Bed5Type   B5OneChromRest;
-  typedef BTOneNoRest::Bed5Type B5OneChromNoRest;
+
+
+  typedef BedTypes<AllChrom, Rest, Bed::MeasurementType, NoPooling>    BTAllRestNoPool;
+  typedef BedTypes<AllChrom, NoRest, Bed::MeasurementType, NoPooling>  BTAllNoRestNoPool;
+
+  typedef BTAllRestNoPool::Bed3Type   B3RestNoPool;
+  typedef BTAllNoRestNoPool::Bed3Type B3NoRestNoPool;
+
+  typedef BTAllRestNoPool::Bed4Type   B4RestNoPool;
+  typedef BTAllNoRestNoPool::Bed4Type B4NoRestNoPool;
+
+  typedef BTAllRestNoPool::Bed5Type   B5RestNoPool;
+  typedef BTAllNoRestNoPool::Bed5Type B5NoRestNoPool;
 } // namespace Bed
 
 #endif // BEDTYPES_HPP
